==> bitmovin-api-sdk-1.92.0.tar.gz: bitmovin-api-sdk-1.92.0/bitmovin_api_sdk/models/cloud_region.py <==
# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class CloudRegion(Enum):
    AWS_US_EAST_1 = "AWS_US_EAST_1"
    AWS_US_EAST_2 = "AWS_US_EAST_2"
    AWS_US_WEST_1 = "AWS_US_WEST_1"
    AWS_US_WEST_2 = "AWS_US_WEST_2"
    AWS_EU_WEST_1 = "AWS_EU_WEST_1"
    AWS_EU_CENTRAL_1 = "AWS_EU_CENTRAL_1"
    AWS_AP_SOUTHEAST_1 = "AWS_AP_SOUTHEAST_1"
    AWS_AP_SOUTHEAST_2 = "AWS_AP_SOUTHEAST_2"
    AWS_AP_NORTHEAST_1 = "AWS_AP_NORTHEAST_1"
    AWS_AP_NORTHEAST_2 = "AWS_AP_NORTHEAST_2"
    AWS_AP_SOUTH_1 = "AWS_AP_SOUTH_1"
    AWS_SA_EAST_1 = "AWS_SA_EAST_1"
    AWS_EU_WEST_2 = "AWS_EU_WEST_2"
    AWS_EU_WEST_3 = "AWS_EU_WEST_3"
    AWS_CA_CENTRAL_1 = "AWS_CA_CENTRAL_1"
    GOOGLE_US_CENTRAL_1 = "GOOGLE_US_CENTRAL_1"
    GOOGLE_US_EAST_1 = "GOOGLE_US_EAST_1"
    GOOGLE_ASIA_EAST_1 = "GOOGLE_ASIA_EAST_1"
    GOOGLE_EUROPE_WEST_1 = "GOOGLE_EUROPE_WEST_1"
    GOOGLE_US_WEST_1 = "GOOGLE_US_WEST_1"
    GOOGLE_ASIA_EAST_2 = "GOOGLE_ASIA_EAST_2"
    GOOGLE_ASIA_NORTHEAST_1 = "GOOGLE_ASIA_NORTHEAST_1"
    GOOGLE_ASIA_SOUTH_1 = "GOOGLE_ASIA_SOUTH_1"
    GOOGLE_ASIA_SOUTHEAST_1 = "GOOGLE_ASIA_SOUTHEAST_1"
    GOOGLE_AUSTRALIA_SOUTHEAST_1 = "GOOGLE_AUSTRALIA_SOUTHEAST_1"
    GOOGLE_EUROPE_NORTH_1 = "GOOGLE_EUROPE_NORTH_1"
    GOOGLE_EUROPE_WEST_2 = "GOOGLE_EUROPE_WEST_2"
    GOOGLE_EUROPE_WEST_3 = "GOOGLE_EUROPE_WEST_3"
    GOOGLE_EUROPE_WEST_4 = "GOOGLE_EUROPE_WEST_4"
    GOOGLE_NORTHAMERICA_NORTHEAST_1 = "GOOGLE_NORTHAMERICA_NORTHEAST_1"
    GOOGLE_SOUTHAMERICA_EAST_1 = "GOOGLE_SOUTHAMERICA_EAST_1"
    GOOGLE_US_EAST_4 = "GOOGLE_US_EAST_4"
    GOOGLE_US_WEST_2 = "GOOGLE_US_WEST_2"
    AZURE_EUROPE_WEST = "AZURE_EUROPE_WEST"
    AZURE_US_WEST2 = "AZURE_US_WEST2"
    AZURE_US_EAST = "AZURE_US_EAST"
    AZURE_AUSTRALIA_SOUTHEAST = "AZURE_AUSTRALIA_SOUTHEAST"
    AZURE_AUSTRALIA_EAST = "AZURE_AUSTRALIA_EAST"
    NORTH_AMERICA = "NORTH_AMERICA"
    SOUTH_AMERICA = "SOUTH_AMERICA"
    EUROPE = "EUROPE"
    AFRICA = "AFRICA"
    ASIA = "ASIA"
    AUSTRALIA = "AUSTRALIA"
    AWS = "AWS"
    GOOGLE = "GOOGLE"
    EXTERNAL = "EXTERNAL"
    AUTO = "AUTO"

==> bitmovin-api-sdk-1.94.0.tar.gz: bitmovin-api-sdk-1.94.0/bitmovin_api_sdk/models/cloud_region.py <==
# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class CloudRegion(Enum):
    AWS_US_EAST_1 = "AWS_US_EAST_1"
    AWS_US_EAST_2 = "AWS_US_EAST_2"
    AWS_US_WEST_1 = "AWS_US_WEST_1"
    AWS_US_WEST_2 = "AWS_US_WEST_2"
    AWS_EU_WEST_1 = "AWS_EU_WEST_1"
    AWS_EU_CENTRAL_1 = "AWS_EU_CENTRAL_1"
    AWS_AP_SOUTHEAST_1 = "AWS_AP_SOUTHEAST_1"
    AWS_AP_SOUTHEAST_2 = "AWS_AP_SOUTHEAST_2"
    AWS_AP_NORTHEAST_1 = "AWS_AP_NORTHEAST_1"
    AWS_AP_NORTHEAST_2 = "AWS_AP_NORTHEAST_2"
    AWS_AP_SOUTH_1 = "AWS_AP_SOUTH_1"
    AWS_SA_EAST_1 = "AWS_SA_EAST_1"
    AWS_EU_WEST_2 = "AWS_EU_WEST_2"
    AWS_EU_WEST_3 = "AWS_EU_WEST_3"
    AWS_CA_CENTRAL_1 = "AWS_CA_CENTRAL_1"
    GOOGLE_US_CENTRAL_1 = "GOOGLE_US_CENTRAL_1"
    GOOGLE_US_EAST_1 = "GOOGLE_US_EAST_1"
    GOOGLE_ASIA_EAST_1 = "GOOGLE_ASIA_EAST_1"
    GOOGLE_EUROPE_WEST_1 = "GOOGLE_EUROPE_WEST_1"
    GOOGLE_US_WEST_1 = "GOOGLE_US_WEST_1"
    GOOGLE_ASIA_EAST_2 = "GOOGLE_ASIA_EAST_2"
    GOOGLE_ASIA_NORTHEAST_1 = "GOOGLE_ASIA_NORTHEAST_1"
    GOOGLE_ASIA_SOUTH_1 = "GOOGLE_ASIA_SOUTH_1"
    GOOGLE_ASIA_SOUTHEAST_1 = "GOOGLE_ASIA_SOUTHEAST_1"
    GOOGLE_AUSTRALIA_SOUTHEAST_1 = "GOOGLE_AUSTRALIA_SOUTHEAST_1"
    GOOGLE_EUROPE_NORTH_1 = "GOOGLE_EUROPE_NORTH_1"
    GOOGLE_EUROPE_WEST_2 = "GOOGLE_EUROPE_WEST_2"
    GOOGLE_EUROPE_WEST_3 = "GOOGLE_EUROPE_WEST_3"
    GOOGLE_EUROPE_WEST_4 = "GOOGLE_EUROPE_WEST_4"
    GOOGLE_NORTHAMERICA_NORTHEAST_1 = "GOOGLE_NORTHAMERICA_NORTHEAST_1"
    GOOGLE_SOUTHAMERICA_EAST_1 = "GOOGLE_SOUTHAMERICA_EAST_1"
    GOOGLE_US_EAST_4 = "GOOGLE_US_EAST_4"
    GOOGLE_US_WEST_2 = "GOOGLE_US_WEST_2"
    AZURE_EUROPE_WEST = "AZURE_EUROPE_WEST"
    AZURE_EUROPE_NORTH = "AZURE_EUROPE_NORTH"
    AZURE_US_WEST2 = "AZURE_US_WEST2"
    AZURE_US_EAST = "AZURE_US_EAST"
    AZURE_AUSTRALIA_SOUTHEAST = "AZURE_AUSTRALIA_SOUTHEAST"
    AZURE_AUSTRALIA_EAST = "AZURE_AUSTRALIA_EAST"
    AZURE_GERMANY_WESTCENTRAL = "AZURE_GERMANY_WESTCENTRAL"
    AZURE_UAE_CENTRAL = "AZURE_UAE_CENTRAL"
    AZURE_UAE_NORTH = "AZURE_UAE_NORTH"
    NORTH_AMERICA = "NORTH_AMERICA"
    SOUTH_AMERICA = "SOUTH_AMERICA"
    EUROPE = "EUROPE"
    AFRICA = "AFRICA"
    ASIA = "ASIA"
    AUSTRALIA = "AUSTRALIA"
    AWS = "AWS"
    GOOGLE = "GOOGLE"
    EXTERNAL = "EXTERNAL"
    AUTO = "AUTO"
